#!/bin/bash
#/****************************************************************
# * email: zhanghui1@nfschina.com
# ***************************************************************/
SYS_ADM="sysadm"
SEC_ADM="secadm"

arch=$(uname -m)

sedcommand="sed -i"

# selinux相关软件包需要提前安装
install_env(){

	if [ -f /usr/share/admin3/installflag ]; then
		echo "软件安装完成" > /dev/null 2>&1
	else
		yum -y install policycoreutils policycoreutils-python-utils > /dev/null 2>&1
		yum -y install libselinux-utils > /dev/null 2>&1
		yum -y install setools-console > /dev/null 2>&1

		yum -y install setroubleshoot-server > /dev/null 2>&1

		yum -y install selinux-policy-mls > /dev/null 2>&1

		yum -y install selinux-policy-doc selinux-policy-devel > /dev/null 2>&1
		touch /usr/share/admin3/installflag
	fi
}

on_update_grub()
{
	if [ ${arch}"x" = "aarch64x" ]; then
		${sedcommand} 's/security=selinux enforcing=0/selinux=1/g' /boot/grub2/grubenv
	else
		${sedcommand} 's/selinux=0/selinux=1/g' /boot/grub2/grubenv
	fi
}

off_update_grub()
{
	if [ ${arch}"x" = "aarch64x" ]; then
		${sedcommand} 's/selinux=1/security=selinux enforcing=0/g' /boot/grub2/grubenv
	else
		${sedcommand} 's/selinux=1/selinux=0/g' /boot/grub2/grubenv
	fi
}

#install_env
enforce_on(){
	${sedcommand} 's/SELINUX=.*/SELINUX=enforcing/g' /etc/selinux/config
	${sedcommand} 's/SELINUXTYPE=.*/SELINUXTYPE=targeted/g' /etc/selinux/config
	setenforce 1
}
targeted_on(){
	#${sedcommand} 's/SELINUX=.*/SELINUX=enforcing/g' /etc/selinux/config
	${sedcommand} 's/SELINUX=.*/SELINUX=permissive/g' /etc/selinux/config
	${sedcommand} 's/SELINUXTYPE=.*/SELINUXTYPE=targeted/g' /etc/selinux/config
	setenforce 0
}

mls_on(){
	${sedcommand} 's/SELINUX=.*/SELINUX=permissive/g' /etc/selinux/config
	${sedcommand} 's/SELINUXTYPE=.*/SELINUXTYPE=mls/g' /etc/selinux/config
}

selinux_off(){
	${sedcommand} 's/SELINUX=.*/SELINUX=disabled/g' /etc/selinux/config
}

admins_off(){
	pushd /usr/share/admin3/reset/kernel > /dev/null 2>&1
	rpm -Uvh ./kernel-modules-4.19.113-* \
		./kernel-tools-libs-4.19.113-* \
		./kernel-tools-4.19.113-* \
		./kernel-4.19.113-* \
		./kernel-headers-4.19.113-* \
		./kernel-core-4.19.113-* --nodeps --force --quiet > /dev/null 2>&1
	popd > /dev/null 2>&1

	pushd /usr/share/admin3/reset/selinux > /dev/null 2>&1
	rpm -Uvh ./selinux-policy-mls-3.14.3-* \
		./selinux-policy-3.14.3-* \
		./selinux-policy-targeted-3.14.3-* --nodeps --force --quiet > /dev/null 2>&1
	popd > /dev/null 2>&1

	restorecon -FR -v /root > /dev/null 2>&1
	restorecon -FR -v /home > /dev/null 2>&1

	usermod -L secadm
	usermod -L auditadm
}

admins_on(){
	pushd /usr/share/admin3/set/kernel > /dev/null 2>&1
	rpm -Uvh ./kernel-modules-4.19.113-* \
		./kernel-tools-libs-4.19.113-* \
		./kernel-tools-4.19.113-* \
		./kernel-4.19.113-* \
		./kernel-headers-4.19.113-* \
		./kernel-core-4.19.113-* --nodeps --force --quiet > /dev/null 2>&1
	popd > /dev/null 2>&1

	#rpm -e --nodeps selinux-policy selinux-policy-targeted selinux-policy-mls
	pushd /usr/share/admin3/set/selinux > /dev/null 2>&1
	rpm -Uvh ./selinux-policy-mls-3.14.3-* \
		./selinux-policy-3.14.3-* \
		./selinux-policy-targeted-3.14.3-* --nodeps --force --quiet > /dev/null 2>&1
	popd > /dev/null 2>&1
	echo "nfschina123" | passwd --stdin root > /dev/null 2>&1
	echo "root password: nfschina123" >> /tmp/admins_passwd

	if ! id -u secadm > /dev/null 2>&1;then
		useradd -m -s /bin/bash secadm
	else
		usermod -U secadm
	fi
	echo "nfschina123" | passwd --stdin secadm > /dev/null 2>&1
	echo "secadm password: nfschina123" >> /tmp/admins_passwd

	if ! id -u auditadm > /dev/null 2>&1;then
		useradd -m -s /bin/bash auditadm
	else
		usermod -U auditadm
	fi
	echo "nfschina123" | passwd --stdin auditadm > /dev/null 2>&1
	echo "auditadm password: nfschina123" >> /tmp/admins_passwd

	fixfiles  -F onboot > /dev/null 2>&1
}

case "${1:0:1}" in
	selinuxtargeted)
		targeted_on
		exit 0
		;;
	selinuxmls)
		mls_on
		exit 0
		;;
	selinuxoff)
		selinux_off
		exit 0
		;;
	adminsmls|1)
		#admins_on
		#mls_on
		enforce_on
		exit 0
		;;
	adminsoff|2)
		targeted_on
		exit 0
		;;
	adminsselinuxoff|3)
		selinux_off
		exit 0
		;;
	*)
		exit 1
		;;
esac

