#!/bin/bash

PAM_RESOURCE_DIR="/opt/nfssec/pam"	# 本模块的pam资源目录
SSHD_CONFIG="/etc/ssh/sshd_config"
RLOGIN_POLICY_FLIE="/etc/nfssec.d/rlogin.dat"
ACCREDIT_POLICY_FILE="/etc/nfssec.d/accredit_config.dat"

auth_pam_rule="@include nfssec-common-auth" # 自定义PAM规则

MOD_TAG="nfssec"

function install_util()
{
    cp ${PAM_RESOURCE_DIR}/${MOD_TAG}_pam_util /usr/bin/
}
function uninstall_util()
{
    rm -rf /usr/bin/${MOD_TAG}_pam_util
}

function install_passwd()
{
	cp -f /etc/pam.d/passwd ${PAM_RESOURCE_DIR}/passwd.${MOD_TAG}.bak
	rm -rf /etc/pam.d/passwd

	cp ${PAM_RESOURCE_DIR}/${MOD_TAG}_pam_psw.so /lib64/security/ 2>/dev/null
	cp ${PAM_RESOURCE_DIR}/${MOD_TAG}_pam_psw.so /lib/x86_64-linux-gnu/security/ 2>/dev/null
	cp ${PAM_RESOURCE_DIR}/${MOD_TAG}-common-password /etc/pam.d/
	cp ${PAM_RESOURCE_DIR}/passwd /etc/pam.d/
	chmod 755 /lib64/security/${MOD_TAG}_pam_psw.so 2>/dev/null
	chmod 755 /lib/x86_64-linux-gnu/security/${MOD_TAG}_pam_psw.so 2>/dev/null
	restorecon /lib64/security/${MOD_TAG}_pam_psw.so 2>/dev/null
	restorecon /lib/x86_64-linux-gnu/security/${MOD_TAG}_pam_psw.so 2>/dev/null
	chcon --reference=/lib64/security /lib64/security/${MOD_TAG}_pam_psw.so 2>/dev/null
	chcon --reference=/lib/x86_64-linux-gnu/security /lib/x86_64-linux-gnu/security/${MOD_TAG}_pam_psw.so 2>/dev/null
	chcon --reference=/etc/pam.d/xserver ${ACCREDIT_POLICY_FILE} 2>/dev/null
}

function uninstall_passwd()
{
	cp -f ${PAM_RESOURCE_DIR}/passwd.${MOD_TAG}.bak /etc/pam.d/passwd
	rm -rf /etc/pam.d/${MOD_TAG}-common-password
	rm -rf /lib64/security/${MOD_TAG}_pam_psw.so
	rm -rf /lib/x86_64-linux-gnu/security/${MOD_TAG}_pam_psw.so
}

function install_sshd()
{
	chcon --reference=/etc/pam.d/sshd ${RLOGIN_POLICY_FLIE} 2>/dev/null
	cp /etc/pam.d/sshd ${PAM_RESOURCE_DIR}/sshd.${MOD_TAG}.bak

	# 检查是否已经存在自定义规则
	grep -q "${MOD_TAG}-common-auth" /etc/pam.d/sshd
	if [ $? -eq 0 ]; then
	    echo "Custom PAM rule already exists in /etc/pam.d/sshd"
	    return 0
	fi

	# 添加自定义规则
	# 在/etc/pam.d/sshd文件的第1行，插入自定义auth规则
	sed -i "1i${auth_pam_rule}" /etc/pam.d/sshd

	cp ${PAM_RESOURCE_DIR}/${MOD_TAG}-common-auth /etc/pam.d/

	cp ${PAM_RESOURCE_DIR}/${MOD_TAG}_pam_login.so /lib64/security/ 2>/dev/null
	cp ${PAM_RESOURCE_DIR}/${MOD_TAG}_pam_login.so /lib/x86_64-linux-gnu/security/ 2>/dev/null

	chmod 755 /lib64/security/${MOD_TAG}_pam_login.so 2>/dev/null
	chmod 755 /lib/x86_64-linux-gnu/security/${MOD_TAG}_pam_login.so 2>/dev/null

	restorecon /lib64/security/${MOD_TAG}_pam_login.so 2>/dev/null
	restorecon /lib/x86_64-linux-gnu/security/${MOD_TAG}_pam_login.so 2>/dev/null

	chcon --reference=/lib64/security /lib64/security/${MOD_TAG}_pam_login.so 2>/dev/null
	chcon --reference=/lib/x86_64-linux-gnu/security /lib/x86_64-linux-gnu/security/${MOD_TAG}_pam_login.so 2>/dev/null
}

function uninstall_sshd()
{
	cp -f ${PAM_RESOURCE_DIR}/sshd.${MOD_TAG}.bak /etc/pam.d/sshd

	rm -rf /etc/pam.d/${MOD_TAG}-common-auth
	rm -rf /lib64/security/${MOD_TAG}_pam_login.so
	rm -rf /lib/x86_64-linux-gnu/security/${MOD_TAG}_pam_login.so
}

function inst_sshd_pam()
{
    line_no=0
    while read line
    do
        line_no=$[$line_no+$[1]]
        if [ ${#line} -gt 6 ]; then
            str=${line:0:6};
            if [  "$str" == "UsePAM" ]; then
                echo $line > ${PAM_RESOURCE_DIR}/sshd_config
                break;
            fi
        fi
        
    done < $SSHD_CONFIG
    sed -i "${line_no}c UsePAM yes" $SSHD_CONFIG
    service sshd restart
}

function uninst_sshd_pam()
{
    old_config=`cat ${PAM_RESOURCE_DIR}/sshd_config`
    line_no=0
    while read line
    do
        line_no=$[$line_no+$[1]]
        if [ ${#line} -gt 6 ]; then
            str=${line:0:6};
            if [  "$str" == "UsePAM" ]; then
                echo $line_no
                break;
            fi
        fi
        
    done < $SSHD_CONFIG
    sed -i "${line_no}c $old_config" $SSHD_CONFIG
    service sshd restart
}

if [ $# -ne 1 ]; then
	echo "Parameter format error!"
	exit 1
fi

if [ `whoami` != "root" ];then
	echo "please use root！"
	exit 1
fi

if [ $1 = "inst" ];then

    install_util
#	install_passwd
	install_sshd
elif [ $1 = "uninst" ];then

#	uninstall_passwd
	uninstall_sshd
    uninstall_util
else
	echo "Usage:$0 <inst | uninst>"
	exit 1
fi 
