#!/bin/bash


product_dir="/opt/nfssec"

NFSSEC_SERVICE_CONFIG=/etc/nfssec.d/service_config

# 函数定义
get_value() 
{
    local file="$1"
    local key="$2"
    local value=$(grep -E "^[^#]*$key=" "$file" | sed -n "s/.*$key=\(.*\)/\1/p")

    echo "$value"
}

# 安装指定模块，安装前进行检查
# $1: 模块所在目录
# $2: 模块名
insmod_with_check()
{
    local module_dir=$1
    local module_name=$2
    local str=""

    str=`lsmod | grep -i -e "${module_name}[[:space:]]"`
    if [ -z "$str" ]; then
        if [ -f "${module_dir}/${module_name}.ko" ]; then
            echo "insmod ${module_dir}/${module_name}.ko..."
            insmod ${module_dir}/${module_name}.ko
            RETVAL=$?
        fi
    fi
}

__load()
{
    export LD_LIBRARY_PATH=${product_dir}/lib/

    # 检查配置文件，根据配置决定是否加载内核模块
    ins_kmod=$(get_value $NFSSEC_SERVICE_CONFIG "ins_kmod")
    if [ "$ins_kmod" == "yes" ]; then
        echo "insmod kmod..."
        
        # insmod_with_check ${product_dir}/bin nfsseck
        # insmod_with_check ${product_dir}/bin nfssecdm

        insmod_with_check ${product_dir}/bin nfssecprot
        insmod_with_check ${product_dir}/bin nfssecmac
        insmod_with_check ${product_dir}/bin nfssecnac

    fi
 
    # insmod ${product_dir}/bin/nfsseck.ko # log_level="debug"

    cd ${product_dir}/bin/
    ./nfssecd --start

    cd ${product_dir}/bin/logd
    ./startApp.sh

    #cd ${product_dir}/bin/commd
    #./startApp.sh

    chcon --reference=/dev/null /dev/NFS_DEVOBJ 2>/dev/null
}

__load
